# Release History

*****************
## Release ONDEWO CSI Python Client 5.2.0

### Improvements
 * Tracking API Version [5.2.0](https://github.com/ondewo/ondewo-csi-api/releases/tag/5.2.0) ( [Documentation](https://ondewo.github.io/ondewo-csi-api/) )


*****************
## Release ONDEWO CSI Python Client 5.1.0

### Improvements
 * Tracking API Version [5.1.0](https://github.com/ondewo/ondewo-csi-api/releases/tag/5.1.0) ( [Documentation](https://ondewo.github.io/ondewo-csi-api/) )


*****************
## Release ONDEWO CSI Python Client 5.0.0

### Improvements
 * Tracking API Version [5.0.0](https://github.com/ondewo/ondewo-csi-api/releases/tag/5.0.0) ( [Documentation](https://ondewo.github.io/ondewo-csi-api/) )

*****************
## Release ONDEWO CSI Python Client 4.0.1

### Improvements
 * Added functionality to pass grpc options to grpc clients based on [ONDEWO CLIENT UTILS PYTHON 2.0.0](https://github.com/ondewo/ondewo-client-utils-python/releases/tag/2.0.0)

*****************
## Release ONDEWO CSI Python Client 4.0.0

### Improvements
 * Tracking API Version [4.0.0](https://github.com/ondewo/ondewo-csi-api/releases/tag/4.0.0) ( [Documentation](https://ondewo.github.io/ondewo-csi-api/) )


*****************
## Release ONDEWO CSI Python Client 3.2.0

### Improvements
 * Tracking API Version [3.2.0](https://github.com/ondewo/ondewo-csi-api/releases/tag/3.2.0) ( [Documentation](https://ondewo.github.io/ondewo-csi-api/) )


*****************

## Release ONDEWO CSI Python Client 3.1.1

### Bug Fixes

* Spelling mistakes fixed synthesize_response
* Examples updated for ondewo-csi-api version 3.1.0


*****************

## Release ONDEWO CSI Python Client 3.1.0

### Improvements

* Tracking API
  Version [3.1.0](https://github.com/ondewo/ondewo-csi-api/releases/tag/3.1.0) ( [Documentation](https://ondewo.github.io/ondewo-csi-api/) )

*****************

## Release ONDEWO CSI Python Client 3.0.1

### Improvements

* Moved library dependencies to SoundFile, pyaudio, pysoundio to requirements-dev.txt

*****************

## Release ONDEWO CSI Python Client 3.0.0

### Improvements

* Tracking API
  Version [3.0.0](https://github.com/ondewo/ondewo-csi-api/releases/tag/3.0.0) ( [Documentation](https://ondewo.github.io/ondewo-csi-api/) )

*****************

## Release ONDEWO CSI Python Client 2.11.1

### New Features

* Upgraded pyaudio>=0.2.12, pysoundio>=2.0.0 and grpc.*>=1.47.0

*****************

## Release ONDEWO CSI Python Client 2.11.0

### New Features

* Upgraded to CSI API Version 2.3.1

*****************

## Release ONDEWO CSI Python Client 2.10.0

### New Features

* Upgraded to CSI API Version 2.3.0

*****************

## Release ONDEWO CSI Python Client 2.9.0

### Improvements

* [[OND211-2039]](https://ondewo.atlassian.net/browse/OND211-2039) - Added pre-commit hooks and adjusted files to them
* Upgraded to CSI API Version 2.0.0

### New Features

* [[OND211-2039]](https://ondewo.atlassian.net/browse/OND211-2039) - Release Automation

*****************

## Release ONDEWO CSI Python Client 2.8.0

### New Features

* Grpc library upgrades
* Ondewo client updates
* Automate proto generation and pypi package creation

*****************

## Release ONDEWO CSI Python Client 2.7.0

### New Features

* Upgrade toondewo-s2t-client 3.1.0
* Added stop_all_control_messages option

*****************

## Release ONDEWO CSI Python Client 2.6.0

### New Features

* Upgrade to ondewo-nlu-client 2.4.2
* Upgrade toondewo-s2t-client 3.0.0
* Upgrade toondewo-t2s-client 3.0.1
* Upgrade toondewo-sip-client 3.2.0

*****************

## Release ONDEWO CSI Python Client 2.5.1

### New Features

* Upgrade to ondewo-nlu-client 2.4.1

*****************

## Release ONDEWO CSI Python Client 2.5.0

### New Features

* Upgrade to ondewo-csi-api 1.4.0 with extended sip control messages

*****************

## Release ONDEWO CSI Python Client 2.4.1

### New Features

* Upgrade to Ondewo Logging 3.1.0

*****************

## Release ONDEWO CSI Python Client 2.4.0

### New Features

* Sip control messages addition and update sip client to 3.2.0

*****************

## Release ONDEWO CSI Python Client 2.2.0

### New Features

* Control messages integration

*****************

## Release ONDEWO CSI Python Client 2.0.0

### New Features

* New client adaptation to new s2t,t2s, and nlu

*****************

## Release ONDEWO CSI Python Client 1.0.0

### New Features

* Updated ondewo-logging version to 2.0.3
* Updated ondewo-s2t-client version to 1.5.0
* Updated ondewo-nlu-client version to 2.0.0
* Add endpoint for control stream

## Release ONDEWO CSI Python Client 0.2.3

### New Features

* Updated ondewo-sip-client version to 2.2.1

## Release ONDEWO CSI Python Client 0.2.2

### New Features

* [OND233-201] add endpoint for checking health of upstream S2T, NLU and T2S servers
* [OND233-213] add possibility to trigger a specific intent in NLU system in the beginning of the conversation
* [OND233-216] add hangup functionality

*****************

## Release ONDEWO CSI Python Client 0.2.1

### New Features

* Double check licenses

*****************

## Release ONDEWO CSI Python Client 0.2.0

### New Features

* New client!

*****************
